@@ -31,8 +31,8 @@ def main():
 
     print_log(
         "Finishing Work Requirements in namespace "
-        f"'{CONFIG_COMMON.namespace}' with "
-        f"'{CONFIG_COMMON.name_tag}' in tag"
+        f"'{CONFIG_COMMON.namespace}' with tags "
+        f"including '{CONFIG_COMMON.name_tag}'"
     )
 
     selected_work_requirement_summaries: List[WorkRequirementSummary] = (
@@ -59,7 +59,7 @@ def main():
         )
 
     if len(selected_work_requirement_summaries) > 0 and confirmed(
-        f"Finish {len(selected_work_requirement_summaries)} " f"Work Requirement(s)?"
+        f"Finish {len(selected_work_requirement_summaries)} Work Requirement(s)?"
     ):
         for work_summary in selected_work_requirement_summaries:
             if work_summary.status != WorkRequirementStatus.FINISHING:
@@ -114,10 +114,7 @@ def _finish_work_requirements_by_name_or_id(names_or_ids: List[str]):
             )
         )
         if work_requirement_summary is None:
-            print_error(
-                f"Work Requirement '{name_or_id}' not found in "
-                f"namespace '{CONFIG_COMMON.namespace}'"
-            )
+            print_error(f"Work Requirement '{name_or_id}' not found")
             continue
 
         if work_requirement_summary.status not in [
