@@ -23,6 +23,7 @@ class ConfigWorkRequirement:
     add_yd_env_vars: bool = False
     always_upload: bool = True
     args: List[str] = field(default_factory=list)
+    batch_allocation: Optional[bool] = None
     completed_task_ttl: Optional[float] = None  # In minutes
     csv_files: Optional[List[str]] = None
     docker_env: Optional[Dict] = None
@@ -52,11 +53,14 @@ class ConfigWorkRequirement:
     providers: Optional[List[str]] = None
     ram: Optional[List[float]] = None
     regions: Optional[List[str]] = None
+    retryable_errors: Optional[List[Dict]] = None
     set_task_names: bool = True
     task_batch_size: int = TASK_BATCH_SIZE_DEFAULT
     task_count: int = 1
     task_data: Optional[str] = None
     task_data_file: Optional[str] = None
+    task_data_inputs: Optional[List[Dict]] = None
+    task_data_outputs: Optional[List[Dict]] = None
     task_group_count: int = 1
     task_group_name: Optional[str] = None
     task_level_timeout: Optional[float] = None
@@ -100,5 +104,6 @@ class ConfigWorkerPool:
     user_data_files: Optional[List[str]] = None
     worker_pool_data_file: Optional[str] = None
     worker_tag: Optional[str] = None
-    workers_per_vcpu: Optional[int] = None
+    workers_custom_command: Optional[str] = None
     workers_per_node: int = 1
+    workers_per_vcpu: Optional[int] = None
